import { FormLayout, IFileOptions, IUploadOptions } from "ng-devui";
import { ControlType } from "./boxInfo";
export interface AttributeInfo {
    name: string;
    controltype: ControlType;
    controlname: string;
    mode: string;
    label: string;
    required: boolean;
    help: boolean;
    helptip?: string;
    defaultvalue: any;
    itemselected: boolean;
    disabled: boolean;
    rules: {};
}
export interface InputInfo extends AttributeInfo {
    placeholder: string;
}
export interface RichIputInfo extends AttributeInfo {
    height: number;
}
export interface SelectInfo extends AttributeInfo {
    placeholder: string;
    filter: string;
    options: any;
    dataType: string;
    postdata: any;
    multiple: boolean;
}
export interface CounterInfo extends AttributeInfo {
    min: number;
    max: number;
    step: number;
    unit: string;
}
export interface AlertInfo extends AttributeInfo {
    alerttype: string;
    closeable: boolean;
}
export interface CheckInfo extends AttributeInfo {
    options: any;
    filter: string;
    direction: string;
    isshowtitle: boolean;
    dataType: string;
    postdata: any;
}
export interface RadioInfo extends AttributeInfo {
    options: any;
    direction: string;
    dataType: string;
    postdata: any;
}
export interface RateInfo extends AttributeInfo {
    allowhalf: boolean;
}
export interface SpaceInfo extends AttributeInfo {
    height: number;
}
export interface DateInfo extends AttributeInfo {
    datetype: string;
    showtime: boolean;
    dateFormat: string;
    placeholder: string;
}
export interface TimeInfo extends AttributeInfo {
    format: string;
    placeholder: string;
}
export interface DividerInfo extends AttributeInfo {
    align: string;
}
export interface UploadInfo extends AttributeInfo {
    uploadOptions: IUploadOptions;
    fileOptions: IFileOptions;
    uploadedFiles: Array<Object>;
    filePath: string;
    showTip: boolean;
    uploadtype: string;
}
export interface TransferInfo extends AttributeInfo {
    options: [];
    dataType: string;
    postdata: any;
    source: string;
    target: string;
}
export interface SlideInfo extends AttributeInfo {
    min: number;
    max: number;
    step: number;
}
export interface TreeInfo extends AttributeInfo {
    placeholder: string;
    options: any;
    dataType: string;
    postdata: any;
}
export interface CanvasInfo {
    layout: FormLayout;
    labelSize: 'sm' | '' | 'lg';
    labelAlign: 'start' | 'center' | 'end';
}
export declare const INPUTDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    defaultvalue: string;
    placeholder: string;
};
export declare const DATEDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    defaultvalue: string;
    datetype: string;
    showtime: boolean;
    dateFormat: string;
    placeholder: string;
};
export declare const TIMEDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    defaultvalue: string;
    format: string;
    placeholder: string;
};
export declare const RICHINPUTDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    height: number;
    defaultvalue: string;
};
export declare const COUNTERDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    defaultvalue: number;
    min: number;
    max: number;
    step: number;
    unit: string;
};
export declare const LAYOUTDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
};
export declare const RATEDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    defaultvalue: number;
    allowhalf: boolean;
};
export declare const TOGGLEDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
};
export declare const DIVIDERDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    align: string;
    alignvalue: {
        label: string;
        value: string;
    };
};
export declare const CANVASDEFAULT: CanvasInfo;
export declare const SELECTDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    defaultvalue: string;
    placeholder: string;
    options: {
        label: string;
        value: string;
    }[];
    filter: string;
    dataType: string;
    postdata: {
        url: string;
        method: string;
        data: {};
        head: {};
        function: string;
    };
    multiple: boolean;
};
export declare const ALERTDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    alerttype: string;
    closeable: boolean;
};
export declare const CHECKDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    direction: string;
    isshowtitle: boolean;
    options: ({
        label: string;
        value: string;
        disabled: boolean;
    } | {
        label: string;
        value: string;
        disabled?: undefined;
    })[];
    filter: string;
    dataType: string;
    postdata: {
        url: string;
        method: string;
        data: {};
        head: {};
        function: string;
    };
};
export declare const RADIODEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    direction: string;
    isshowtitle: boolean;
    options: string[];
    dataType: string;
    postdata: {
        url: string;
        method: string;
        data: {};
        head: {};
        function: string;
    };
};
export declare const SPACEDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    controltype: ControlType;
    height: number;
};
export declare const UPLOADDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    fileOptions: {
        accept: string;
        multiple: boolean;
    };
    uploadOptions: {
        uri: string;
        headers: {};
        additionalParameter: {};
        maximumSize: number;
        method: string;
        fileFieldName: string;
        withCredentials: boolean;
        responseType: string;
    };
    uploadedFiles: any[];
    filePath: string;
    uploadtype: string;
};
export declare const SLIDEDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    defaultvalue: number;
    min: number;
    max: number;
    step: number;
};
export declare const TRANSFERDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    options: ({
        name: string;
        value: number;
        id: number;
        disabled?: undefined;
    } | {
        name: string;
        value: number;
        id: number;
        disabled: boolean;
    })[];
    defaultvalue: any[];
    dataType: string;
    postdata: {
        url: string;
        method: string;
        data: {};
        head: {};
        function: string;
    };
    source: string;
    target: string;
};
export declare const TREEDEFAULT: {
    required: boolean;
    help: boolean;
    mode: string;
    disabled: boolean;
    label: string;
    controltype: ControlType;
    placeholder: string;
    defaultvalue: any;
    dataType: string;
    options: ({
        label: string;
        value: number;
        children?: undefined;
        isLeaf?: undefined;
        disabled?: undefined;
    } | {
        label: string;
        value: number;
        children: any[];
        isLeaf: boolean;
        disabled: boolean;
    })[];
    postdata: {
        url: string;
        method: string;
        data: {};
        head: {};
        function: string;
    };
};
export declare const MAINCONTAINER = "mainarea";
